OiRA

# Zertifikat

This certificate is presented to

Sacrebleu & Fils

For conducting a risk assessment with the tool “Transport routier” on 7 September 2019.

Name on certificate Departement/Region SIRET number Contact name
Make public

Your certificate for “Buckets and broomsticks” is private unless you choose to make it public. By ticking the “Make public” tickbox above, your certificate will be published on the official OiRA website.

Back

## certificate-public.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More